LambdaRegistry

Struct LambdaRegistry 

pub struct LambdaRegistry { /* private fields */ }
Maps JIT code pointers to human-readable lambda names.

Populated during compilation, queried during execution to identify which closure is being called when debugging crashes.

Implementations

Source

impl LambdaRegistry

pub fn new() -> Self

pub fn register(&mut self, code_ptr: usize, name: String)

Register a lambda’s code pointer and name.

pub fn lookup(&self, code_ptr: usize) -> Option<&str>

Look up a lambda name by code pointer.

pub fn lookup_by_address(&self, addr: usize) -> Option<&str>

Look up a lambda name by an address within its body. Finds the entry point <= addr that is closest to addr.

pub fn len(&self) -> usize

Number of registered lambdas.

pub fn is_empty(&self) -> bool