Module frame_walker

Module frame_walker 

Structs

StackRoot
A collected GC root: the address on the stack where a heap pointer lives.

Functions

rewrite_roots
Rewrite forwarding pointers in stack slots after GC.
walk_frames
Walk JIT frames starting from the given frame pointer, collecting all GC roots.