pub struct LambdaRegistry { /* private fields */ }Expand description
Maps JIT code pointers to human-readable lambda names.
Populated during compilation, queried during execution to identify which closure is being called when debugging crashes.
Implementations
Sourceimpl LambdaRegistry
impl LambdaRegistry
pub fn new() -> Self
Sourcepub fn register(&mut self, code_ptr: usize, name: String)
pub fn register(&mut self, code_ptr: usize, name: String)
Register a lambda’s code pointer and name.
Sourcepub fn lookup_by_address(&self, addr: usize) -> Option<&str>
pub fn lookup_by_address(&self, addr: usize) -> Option<&str>
Look up a lambda name by an address within its body. Finds the entry point <= addr that is closest to addr.
pub fn is_empty(&self) -> bool