pub unsafe extern "C" fn debug_app_check(
fun_ptr: *const u8,
) -> *mut u8Expand description
Returns 0 if the call is safe to proceed, or a poison pointer if the call should be short-circuited (runtime error already set or call depth exceeded).
Safety
fun_ptr must point to a valid HeapObject or be null.