pub extern "C" fn runtime_case_trap(
scrut_ptr: i64,
num_alts: i64,
alt_tags: i64,
) -> *mut u8Expand description
Debug: called instead of trap user2 when TIDEPOOL_DEBUG_CASE is set.
Prints diagnostic info about the scrutinee that failed case matching.
scrut_ptr is the heap pointer to the scrutinee.
num_alts is the number of data alt tags expected.
alt_tags is a pointer to an array of expected tag u64 values.