pub extern "C" fn trampoline_resolve(vmctx: *mut VMContext) -> *mut u8Expand description
Resolve pending tail calls from VMContext. Called by non-tail App sites when the callee returned null (indicating a tail call was stored).
Loop: read tail_callee+tail_arg from VMContext, clear them, call the closure, check if result is null (another tail call) or a real value.