pub struct JitEffectMachine { /* private fields */ }Expand description
High-level JIT effect machine — compile and run freer-simple effect stacks without touching raw pointers, nurseries, or stack maps.
Implementations
Sourceimpl JitEffectMachine
impl JitEffectMachine
Sourcepub fn compile(
expr: &CoreExpr,
table: &DataConTable,
nursery_size: usize,
) -> Result<Self, JitError>
pub fn compile( expr: &CoreExpr, table: &DataConTable, nursery_size: usize, ) -> Result<Self, JitError>
Compile a CoreExpr for JIT execution.
Sourcepub fn run<U, H: DispatchEffect<U>>(
&mut self,
table: &DataConTable,
handlers: &mut H,
user: &U,
) -> Result<Value, JitError>
pub fn run<U, H: DispatchEffect<U>>( &mut self, table: &DataConTable, handlers: &mut H, user: &U, ) -> Result<Value, JitError>
Run to completion, dispatching effects through the handler HList.